@@ -14,23 +14,32 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
 
 #ifndef SERVICECONFIGWIDGET_H
 #define SERVICECONFIGWIDGET_H
 
-#include <serviceconfigdata.h>
+#include <ui_serviceconfigdata.h>
+
+class Q3ListViewItem;
+class OrgKdeKweatherServiceInterface;
+
+class wsPrefs : public QWidget, public Ui::wsPrefs
+{
+public:
+  wsPrefs( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
 
-class QListViewItem;
-class WeatherService_stub;
 
 class ServiceConfigWidget : public wsPrefs
 {
   Q_OBJECT
 
   public:
-    ServiceConfigWidget( QWidget *parent, const char *name = 0 );
+    explicit ServiceConfigWidget( QWidget *parent );
     virtual ~ServiceConfigWidget();
 
   signals:
@@ -42,17 +51,17 @@ class ServiceConfigWidget : public wsPrefs
     void updateStations();
     void exitWeatherService();
 
-    void selectionChanged( QListViewItem* );
+    void selectionChanged( Q3ListViewItem* );
     void modified();
 
   private:
     void initGUI();
     void loadLocations();
-    bool dcopActive();
+    bool dbusActive();
     void scanStations();
 
     QMap<QString, QString> mStationMap;
-    WeatherService_stub *mService;
+    OrgKdeKweatherServiceInterface *mService;
 };
 
 #endif
